.. py:currentmodule:: rubin_sim

.. _user-guide:

##########
User Guide
##########


.. toctree::

    Data Download Utilities <data-download>

    Metrics Analysis Framework (MAF) <maf>

    Moving Objects <moving-objects>

    Phot Utils <phot-utils>

    Satellite Constellations <satellite-constellations>

    Self Calibration <selfcal>

    Skybrightness <skybrightness>


 
